[Libreoffice-commits] core.git: sw/source

Jan Holesovsky kendy at collabora.com
Tue May 12 06:21:49 PDT 2015


 sw/source/uibase/inc/content.hxx    |    4 ++--
 sw/source/uibase/utlui/numfmtlb.cxx |   30 +++++++++++++++---------------
 2 files changed, 17 insertions(+), 17 deletions(-)

New commits:
commit 083b54c7d198ae402e9038a930a66be818475ac3
Author: Jan Holesovsky <kendy at collabora.com>
Date:   Tue May 12 15:20:51 2015 +0200

    sw: More renaming.
    
    Change-Id: I7f8d0d7285a95899484ec972ae38bdb8543ae2e1

diff --git a/sw/source/uibase/inc/content.hxx b/sw/source/uibase/inc/content.hxx
index 4029997..d065065 100644
--- a/sw/source/uibase/inc/content.hxx
+++ b/sw/source/uibase/inc/content.hxx
@@ -95,10 +95,10 @@ class SwPostItContent : public SwContent
 public:
     SwPostItContent( const SwContentType* pCnt,
                             const OUString& rName,
-                            const SwFmtFld* pField,
+                            const SwFmtFld* pFormatField,
                             long nYPos )
         : SwContent(pCnt, rName, nYPos)
-        , pFld(pField)
+        , pFld(pFormatField)
         , pRedline(NULL)
         , mbPostIt(true)
     {}
diff --git a/sw/source/uibase/utlui/numfmtlb.cxx b/sw/source/uibase/utlui/numfmtlb.cxx
index 953032b..a12a7ce 100644
--- a/sw/source/uibase/utlui/numfmtlb.cxx
+++ b/sw/source/uibase/utlui/numfmtlb.cxx
@@ -52,7 +52,7 @@ using namespace ::com::sun::star::lang;
 /**
  *  Description:
  *     nFormatType: Display the formats of this Type
  *     nDefFmt:     Select this format and possibly insert it
  */
 
 NumFormatListBox::NumFormatListBox(vcl::Window* pWin, WinBits nStyle) :
@@ -270,11 +270,11 @@ void NumFormatListBox::SetFormatType(const short nFormatType)
     }
 }
 
-void NumFormatListBox::SetDefFormat(const sal_uLong nDefFmt)
+void NumFormatListBox::SetDefFormat(const sal_uLong nDefaultFormat)
 {
-    if (nDefFmt == ULONG_MAX)
+    if (nDefaultFormat == ULONG_MAX)
     {
-        nDefFormat = nDefFmt;
+        nDefFormat = nDefaultFormat;
         return;
     }
 
@@ -291,11 +291,11 @@ void NumFormatListBox::SetDefFormat(const sal_uLong nDefFmt)
         pFormatter = rSh.GetNumberFormatter();
     }
 
-    short nType = pFormatter->GetType(nDefFmt);
+    short nType = pFormatter->GetType(nDefaultFormat);
 
     SetFormatType(nType);
 
-    sal_uLong nFormat = pFormatter->GetFormatForLanguageIfBuiltIn(nDefFmt, eCurLanguage);
+    sal_uLong nFormat = pFormatter->GetFormatForLanguageIfBuiltIn(nDefaultFormat, eCurLanguage);
 
     for (sal_Int32 i = 0; i < GetEntryCount(); i++)
     {
@@ -315,11 +315,11 @@ void NumFormatListBox::SetDefFormat(const sal_uLong nDefFmt)
 
     if (nType == css::util::NumberFormat::TEXT)
     {
-        pFormatter->GetOutputString("\"ABC\"", nDefFmt, sValue, &pCol);
+        pFormatter->GetOutputString("\"ABC\"", nDefaultFormat, sValue, &pCol);
     }
     else
     {
-        pFormatter->GetOutputString(fValue, nDefFmt, sValue, &pCol);
+        pFormatter->GetOutputString(fValue, nDefaultFormat, sValue, &pCol);
     }
 
     sal_Int32 nPos = 0;
@@ -337,15 +337,15 @@ void NumFormatListBox::SetDefFormat(const sal_uLong nDefFmt)
     sal_uLong nLongDateFormatForLanguage = pFormatter->GetFormatForLanguageIfBuiltIn(nSysLongDateFmt, LANGUAGE_SYSTEM );
 
     if (
-         nDefFmt == nSysNumFmt ||
-         nDefFmt == nSysShortDateFmt ||
-         nDefFmt == nSysLongDateFmt ||
+         nDefaultFormat == nSysNumFmt ||
+         nDefaultFormat == nSysShortDateFmt ||
+         nDefaultFormat == nSysLongDateFmt ||
          (
            bSysLang &&
            (
-             nDefFmt == nNumFormatForLanguage ||
-             nDefFmt == nShortDateFormatForLanguage ||
-             nDefFmt == nLongDateFormatForLanguage
+             nDefaultFormat == nNumFormatForLanguage ||
+             nDefaultFormat == nShortDateFormatForLanguage ||
+             nDefaultFormat == nLongDateFormatForLanguage
            )
          )
        )
@@ -354,7 +354,7 @@ void NumFormatListBox::SetDefFormat(const sal_uLong nDefFmt)
     }
 
     nPos = InsertEntry(sValue, nPos);   // Insert as first numeric entry
-    SetEntryData(nPos, reinterpret_cast<void*>(nDefFmt));
+    SetEntryData(nPos, reinterpret_cast<void*>(nDefaultFormat));
     SelectEntryPos(nPos);
     nDefFormat = GetFormat();
 }
@@ -52,7 +52,7 @@ using namespace ::com::sun::star::lang;
  *  Description:
  *     nFormatType: Display the formats of this Type
- *     nDefFmt:     Select this format and possibly insert it
+ *     nDefaultFormat: Select this format and possibly insert it
  */
 


More information about the Libreoffice-commits mailing list